/* Program09_6
 *
 * Ez a program az I2C1 buszon keresztül kezeli 
 * az SSD1306 vezérlővel ellátott 128x32 OLED kijelzőt.
 *
 * A 128x32 pixeles vezérlő nem teljesen kompatibilis 
 * a 128x64 pixeles SSD1306 kijelzővel, apróbb különbségek 
 * vannak az inicializálásban
 * Az ebben a projetben használt ssd1306.h és ssd1306.c
 * forrásfájlok már tartalmazzák a szükséges módosításokat 
 * Az I2C kapcsolat fixen PB8, PB9-hez rendelt, 400 kHz sebességű.
 *
 * Kapcsolás:
 *   --------           --------------
 *  | STM32  |         | SSD1306 OLED |
 *  |    PB9 |---------| SDA          |
 *  |    PB8 |---------| SCL          | 
 *  |    VCC |---------| VCC         |
 *  |    GND |---------| GND          |
 *   --------           --------------
 *
 * Felhasznált források: 
 * Mazidi et al., STM32 Arm Programming for Embedded Systems    
 * http://www.microdigitaled.com/ARM/STM_ARM_books.html
 *
 * Controllerstech: OLED display using I2C and STM32
 * https://controllerstech.com/oled-display-using-i2c-stm32/
 *
 * Alexander Lutsai: Блиблиотека OLED дисплея SSD1306 для STM32 микроконтроллеров
 * https://lutsai.ru/stm32/2016/03/08/Library-ssd1306-stm32.html
 *
 * Tested with Keil MDK-Lite v5.28 and STM32F1 DFP v2.3.0
 */
 
#include "stm32f10x.h"
#include "ssd1306.h"

int main(void) {
  SSD1306_Init();            // inicializálás
  //--- Írjunk ki valamit! -----------------
  SSD1306_GotoXY(5, 1);
  SSD1306_Puts("2020-FEB-12 TUE", &Font_7x10, SSD1306_COLOR_WHITE);
  SSD1306_GotoXY(5, 12);
  SSD1306_Puts(" 17:30:45", &Font_11x18, SSD1306_COLOR_WHITE);
  /* 
  //-- Egy másik kiírási lehetőség ---------
  SSD1306_GotoXY(2, 2);
  SSD1306_Puts("HELLO", &Font_11x18, SSD1306_COLOR_WHITE);
  SSD1306_GotoXY(60, 13);
  SSD1306_Puts("WORLD!", &Font_11x18, SSD1306_COLOR_WHITE);
  //--- Keretező téglalap kirajzolása ------
  SSD1306_DrawRectangle(0,0,127,31,SSD1306_COLOR_WHITE);
  */
  SSD1306_UpdateScreen();    // Megjelenítés
  while(1) { }
}







